use anyhow::Result;
use structopt::StructOpt;

mod changelog;
mod cmd;
mod git;
mod version;

pub(crate) use cmd::*;

// Name your user agent after your app?
pub(crate) static APP_USER_AGENT: &str =
    concat!(env!("CARGO_PKG_NAME"), "/", env!("CARGO_PKG_VERSION"));

#[tokio::main]
async fn main() -> Result<()> {
    let _ = kankyo::init();
    let cmd = cmd::Cmd::from_args();

    match cmd {
        Cmd::Cut {
            common,
            changelog,
            tag,
            release_meta,
        } => cmd::cut::run(common, changelog, tag, release_meta).await,
        Cmd::DronePlugin { env } => cmd::drone_plugin::run(env).await,
    }
}
